@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -31,14 +31,14 @@
 wrapper(__open, int, (const char * pathname, int flags, ...))
 {
     int mode = 0;
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
+
+    va_list arg;
+    va_start(arg, flags);
 
     debug("__open(\"%s\", %d, ...)", pathname, flags);
-    expand_chroot_path(pathname, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(pathname);
 
     if (flags & O_CREAT) {
-        va_list arg;
-        va_start(arg, flags);
         mode = va_arg(arg, int);
         va_end(arg);
     }
@@ -46,4 +46,6 @@ wrapper(__open, int, (const char * pathname, int flags, ...))
     return nextcall(__open)(pathname, flags, mode);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
