@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -29,10 +29,11 @@
 
 wrapper(dlmopen, void *, (Lmid_t nsid, const char * filename, int flag))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("dlmopen(&nsid, \"%s\", %d)", filename, flag);
-    expand_chroot_path(filename, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(filename);
     return nextcall(dlmopen)(nsid, filename, flag);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
