@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -28,10 +28,11 @@
 
 wrapper(inotify_add_watch, int, (int fd, const char * pathname, uint32_t mask))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("inotify_add_watch(%d, \"%s\", %d)", fd, pathname, mask);
-    expand_chroot_path(pathname, fakechroot_path, fakechroot_buf);
+    expand_chroot_path(pathname);
     return nextcall(inotify_add_watch)(fd, pathname, mask);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
