@@ -1,6 +1,6 @@
 /*
     libfakechroot -- fake chroot environment
-    Copyright (c) 2010 Piotr Roszatycki <dexter@debian.org>
+    Copyright (c) 2010, 2013 Piotr Roszatycki <dexter@debian.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -28,10 +28,11 @@
 
 wrapper(unlinkat, int, (int dirfd, const char * pathname, int flags))
 {
-    char *fakechroot_path, fakechroot_buf[FAKECHROOT_PATH_MAX];
     debug("unlinkat(%d, \"%s\", %d)", dirfd, pathname, flags);
-    expand_chroot_path(pathname, fakechroot_path, fakechroot_buf);
+    expand_chroot_path_at(dirfd, pathname);
     return nextcall(unlinkat)(dirfd, pathname, flags);
 }
 
+#else
+typedef int empty_translation_unit;
 #endif
